@@ -22,34 +22,10 @@ def gen_ru_words(check: int):
         letters = input("Write in this line: ")
         print("Write length of words which do you need")
         length_of_words = int(input("Write in this line: "))
-        name_of_file = 'russian_nouns.txt'
-        file = open(name_of_file, 'r', encoding='utf-8')
-        list_of_ru_words = []
-        for i in range(51300):
-            list_of_ru_words.append(file.readline()[0:-1])
-        result = ""
-        result += f"Слова из {length_of_words} букв:        \n"
-        words = set(itertools.permutations(letters, r=length_of_words))
-        count_2 = 1
-        for word in words:
-            count = 0
-            generate_word = "".join(word)
-            for j in range(len(list_of_ru_words)):
-                if generate_word == list_of_ru_words[j] and count == 0:
-                    result += f"{count_2} слово: {generate_word}        \n"
-                    count += 1
-                    count_2 += 1
-        print(result)
-
-    elif check == 0:
-        def generator():
-            letters = txt.get()
-            length_of_words = int(combo.get())
-            name_of_file = 'russian_nouns.txt'
-            file = open(name_of_file, 'r', encoding='utf-8')
+        with open('russian_nouns.txt', encoding='utf-8') as f:
             list_of_ru_words = []
             for i in range(51300):
-                list_of_ru_words.append(file.readline()[0:-1])
+                list_of_ru_words.append(f.readline()[0:-1])
             result = ""
             result += f"Слова из {length_of_words} букв:        \n"
             words = set(itertools.permutations(letters, r=length_of_words))
@@ -62,6 +38,28 @@ def gen_ru_words(check: int):
                         result += f"{count_2} слово: {generate_word}        \n"
                         count += 1
                         count_2 += 1
+        print(result)
+
+    elif check == 0:
+        def generator():
+            letters = txt.get()
+            length_of_words = int(combo.get())
+            with open('russian_nouns.txt', encoding='utf-8') as f:
+                list_of_ru_words = []
+                for i in range(51300):
+                    list_of_ru_words.append(f.readline()[0:-1])
+                result = ""
+                result += f"Слова из {length_of_words} букв:        \n"
+                words = set(itertools.permutations(letters, r=length_of_words))
+                count_2 = 1
+                for word in words:
+                    count = 0
+                    generate_word = "".join(word)
+                    for j in range(len(list_of_ru_words)):
+                        if generate_word == list_of_ru_words[j] and count == 0:
+                            result += f"{count_2} слово: {generate_word}        \n"
+                            count += 1
+                            count_2 += 1
             messagebox.showinfo("Результаты", result)
 
         window = Tk()
