@@ -24,8 +24,8 @@ def pip_upgrade():
 
 def required():
     require = ["requests", "opencv-python", "progress"]
-    print("Установка необходимых библиотек")
+    print("Установка необходимых библиотек...")
     for i in range(len(require)):
         install(require[i], check=False)
-        print(f"{i + 1}/{len(require)}")
-    print("Установка завершена")
+        print(f"Status: {i + 1} of {len(require)}")
+    print("Установка завершена.")
\ No newline at end of file
